# calculator Toolkit
`calculator_toolkit` is a simple Python package for basic calculations.


## Installation
Install the package with pip:
pip install calculator_toolkit



Usage
from calculator_toolkit import (
 add,
 subtract,
 multiply,
 divide,
 power
)